@@ -4,7 +4,7 @@ import matplotlib.pyplot as plt
 #from matplotlib.dates import DateFormatter
 
 
-class plot():
+class Plot():
     """
     This class is built over matplotlib library in a way to automate and help
     publishers to automate and manipulate their plots to include it into their scientific papers
